# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vssref_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13vssref_common.proto\x12\x06VSSRef\"D\n\x05Robot\x12\x10\n\x08robot_id\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\x13\n\x0borientation\x18\x04 \x01(\x01\"H\n\x05\x46rame\x12 \n\tteamColor\x18\x01 \x01(\x0e\x32\r.VSSRef.Color\x12\x1d\n\x06robots\x18\x02 \x03(\x0b\x32\r.VSSRef.Robot*s\n\x04\x46oul\x12\r\n\tFREE_KICK\x10\x00\x12\x10\n\x0cPENALTY_KICK\x10\x01\x12\r\n\tGOAL_KICK\x10\x02\x12\r\n\tFREE_BALL\x10\x03\x12\x0b\n\x07KICKOFF\x10\x04\x12\x08\n\x04STOP\x10\x05\x12\x0b\n\x07GAME_ON\x10\x06\x12\x08\n\x04HALT\x10\x07*\'\n\x05\x43olor\x12\x08\n\x04\x42LUE\x10\x00\x12\n\n\x06YELLOW\x10\x01\x12\x08\n\x04NONE\x10\x02*[\n\x08Quadrant\x12\x0f\n\x0bNO_QUADRANT\x10\x00\x12\x0e\n\nQUADRANT_1\x10\x01\x12\x0e\n\nQUADRANT_2\x10\x02\x12\x0e\n\nQUADRANT_3\x10\x03\x12\x0e\n\nQUADRANT_4\x10\x04*~\n\x04Half\x12\x0b\n\x07NO_HALF\x10\x00\x12\x0e\n\nFIRST_HALF\x10\x01\x12\x0f\n\x0bSECOND_HALF\x10\x02\x12\x17\n\x13OVERTIME_FIRST_HALF\x10\x03\x12\x18\n\x14OVERTIME_SECOND_HALF\x10\x04\x12\x15\n\x11PENALTY_SHOOTOUTS\x10\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vssref_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FOUL._serialized_start=175
  _FOUL._serialized_end=290
  _COLOR._serialized_start=292
  _COLOR._serialized_end=331
  _QUADRANT._serialized_start=333
  _QUADRANT._serialized_end=424
  _HALF._serialized_start=426
  _HALF._serialized_end=552
  _ROBOT._serialized_start=31
  _ROBOT._serialized_end=99
  _FRAME._serialized_start=101
  _FRAME._serialized_end=173
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Ball(_message.Message):
    __slots__ = ["vx", "vy", "vz", "x", "y", "z"]
    VX_FIELD_NUMBER: _ClassVar[int]
    VY_FIELD_NUMBER: _ClassVar[int]
    VZ_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    Z_FIELD_NUMBER: _ClassVar[int]
    vx: float
    vy: float
    vz: float
    x: float
    y: float
    z: float
    def __init__(self, x: _Optional[float] = ..., y: _Optional[float] = ..., z: _Optional[float] = ..., vx: _Optional[float] = ..., vy: _Optional[float] = ..., vz: _Optional[float] = ...) -> None: ...

class Field(_message.Message):
    __slots__ = ["center_radius", "goal_depth", "goal_width", "length", "penalty_depth", "penalty_point", "penalty_width", "width"]
    CENTER_RADIUS_FIELD_NUMBER: _ClassVar[int]
    GOAL_DEPTH_FIELD_NUMBER: _ClassVar[int]
    GOAL_WIDTH_FIELD_NUMBER: _ClassVar[int]
    LENGTH_FIELD_NUMBER: _ClassVar[int]
    PENALTY_DEPTH_FIELD_NUMBER: _ClassVar[int]
    PENALTY_POINT_FIELD_NUMBER: _ClassVar[int]
    PENALTY_WIDTH_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    center_radius: float
    goal_depth: float
    goal_width: float
    length: float
    penalty_depth: float
    penalty_point: float
    penalty_width: float
    width: float
    def __init__(self, width: _Optional[float] = ..., length: _Optional[float] = ..., goal_width: _Optional[float] = ..., goal_depth: _Optional[float] = ..., center_radius: _Optional[float] = ..., penalty_width: _Optional[float] = ..., penalty_depth: _Optional[float] = ..., penalty_point: _Optional[float] = ...) -> None: ...

class Frame(_message.Message):
    __slots__ = ["ball", "robots_blue", "robots_yellow"]
    BALL_FIELD_NUMBER: _ClassVar[int]
    ROBOTS_BLUE_FIELD_NUMBER: _ClassVar[int]
    ROBOTS_YELLOW_FIELD_NUMBER: _ClassVar[int]
    ball: Ball
    robots_blue: _containers.RepeatedCompositeFieldContainer[Robot]
    robots_yellow: _containers.RepeatedCompositeFieldContainer[Robot]
    def __init__(self, ball: _Optional[_Union[Ball, _Mapping]] = ..., robots_yellow: _Optional[_Iterable[_Union[Robot, _Mapping]]] = ..., robots_blue: _Optional[_Iterable[_Union[Robot, _Mapping]]] = ...) -> None: ...

class Robot(_message.Message):
    __slots__ = ["orientation", "robot_id", "vorientation", "vx", "vy", "x", "y"]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    ROBOT_ID_FIELD_NUMBER: _ClassVar[int]
    VORIENTATION_FIELD_NUMBER: _ClassVar[int]
    VX_FIELD_NUMBER: _ClassVar[int]
    VY_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    orientation: float
    robot_id: int
    vorientation: float
    vx: float
    vy: float
    x: float
    y: float
    def __init__(self, robot_id: _Optional[int] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., orientation: _Optional[float] = ..., vx: _Optional[float] = ..., vy: _Optional[float] = ..., vorientation: _Optional[float] = ...) -> None: ...



import command_pb2 as _command_pb2
import replacement_pb2 as _replacement_pb2
import common_pb2 as _common_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Environment(_message.Message):
    __slots__ = ["field", "frame", "goals_blue", "goals_yellow", "step"]
    FIELD_FIELD_NUMBER: _ClassVar[int]
    FRAME_FIELD_NUMBER: _ClassVar[int]
    GOALS_BLUE_FIELD_NUMBER: _ClassVar[int]
    GOALS_YELLOW_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    field: _common_pb2.Field
    frame: _common_pb2.Frame
    goals_blue: int
    goals_yellow: int
    step: int
    def __init__(self, step: _Optional[int] = ..., frame: _Optional[_Union[_common_pb2.Frame, _Mapping]] = ..., field: _Optional[_Union[_common_pb2.Field, _Mapping]] = ..., goals_blue: _Optional[int] = ..., goals_yellow: _Optional[int] = ...) -> None: ...

class Packet(_message.Message):
    __slots__ = ["cmd", "replace"]
    CMD_FIELD_NUMBER: _ClassVar[int]
    REPLACE_FIELD_NUMBER: _ClassVar[int]
    cmd: _command_pb2.Commands
    replace: _replacement_pb2.Replacement
    def __init__(self, cmd: _Optional[_Union[_command_pb2.Commands, _Mapping]] = ..., replace: _Optional[_Union[_replacement_pb2.Replacement, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Command(_message.Message):
    __slots__ = ["id", "wheel_left", "wheel_right", "yellowteam"]
    ID_FIELD_NUMBER: _ClassVar[int]
    WHEEL_LEFT_FIELD_NUMBER: _ClassVar[int]
    WHEEL_RIGHT_FIELD_NUMBER: _ClassVar[int]
    YELLOWTEAM_FIELD_NUMBER: _ClassVar[int]
    id: int
    wheel_left: float
    wheel_right: float
    yellowteam: bool
    def __init__(self, id: _Optional[int] = ..., yellowteam: bool = ..., wheel_left: _Optional[float] = ..., wheel_right: _Optional[float] = ...) -> None: ...

class Commands(_message.Message):
    __slots__ = ["robot_commands"]
    ROBOT_COMMANDS_FIELD_NUMBER: _ClassVar[int]
    robot_commands: _containers.RepeatedCompositeFieldContainer[Command]
    def __init__(self, robot_commands: _Optional[_Iterable[_Union[Command, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vssref_placement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import vssref_common_pb2 as vssref__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16vssref_placement.proto\x12\x12VSSRef.team_to_ref\x1a\x13vssref_common.proto\"0\n\x10VSSRef_Placement\x12\x1c\n\x05world\x18\x01 \x01(\x0b\x32\r.VSSRef.Frameb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vssref_placement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VSSREF_PLACEMENT._serialized_start=67
  _VSSREF_PLACEMENT._serialized_end=115
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\x0c\x66ira_message\"K\n\x04\x42\x61ll\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\n\n\x02vx\x18\x04 \x01(\x01\x12\n\n\x02vy\x18\x05 \x01(\x01\x12\n\n\x02vz\x18\x06 \x01(\x01\"r\n\x05Robot\x12\x10\n\x08robot_id\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\x13\n\x0borientation\x18\x04 \x01(\x01\x12\n\n\x02vx\x18\x05 \x01(\x01\x12\n\n\x02vy\x18\x06 \x01(\x01\x12\x14\n\x0cvorientation\x18\x07 \x01(\x01\"\xaa\x01\n\x05\x46ield\x12\r\n\x05width\x18\x01 \x01(\x01\x12\x0e\n\x06length\x18\x02 \x01(\x01\x12\x12\n\ngoal_width\x18\x03 \x01(\x01\x12\x12\n\ngoal_depth\x18\x04 \x01(\x01\x12\x15\n\rcenter_radius\x18\x05 \x01(\x01\x12\x15\n\rpenalty_width\x18\x06 \x01(\x01\x12\x15\n\rpenalty_depth\x18\x07 \x01(\x01\x12\x15\n\rpenalty_point\x18\x08 \x01(\x01\"\x7f\n\x05\x46rame\x12 \n\x04\x62\x61ll\x18\x01 \x01(\x0b\x32\x12.fira_message.Ball\x12*\n\rrobots_yellow\x18\x02 \x03(\x0b\x32\x13.fira_message.Robot\x12(\n\x0brobots_blue\x18\x03 \x03(\x0b\x32\x13.fira_message.Robotb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BALL._serialized_start=30
  _BALL._serialized_end=105
  _ROBOT._serialized_start=107
  _ROBOT._serialized_end=221
  _FIELD._serialized_start=224
  _FIELD._serialized_end=394
  _FRAME._serialized_start=396
  _FRAME._serialized_end=523
# @@protoc_insertion_point(module_scope)



import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BallReplacement(_message.Message):
    __slots__ = ["vx", "vy", "x", "y"]
    VX_FIELD_NUMBER: _ClassVar[int]
    VY_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    vx: float
    vy: float
    x: float
    y: float
    def __init__(self, x: _Optional[float] = ..., y: _Optional[float] = ..., vx: _Optional[float] = ..., vy: _Optional[float] = ...) -> None: ...

class Replacement(_message.Message):
    __slots__ = ["ball", "robots"]
    BALL_FIELD_NUMBER: _ClassVar[int]
    ROBOTS_FIELD_NUMBER: _ClassVar[int]
    ball: BallReplacement
    robots: _containers.RepeatedCompositeFieldContainer[RobotReplacement]
    def __init__(self, ball: _Optional[_Union[BallReplacement, _Mapping]] = ..., robots: _Optional[_Iterable[_Union[RobotReplacement, _Mapping]]] = ...) -> None: ...

class RobotReplacement(_message.Message):
    __slots__ = ["position", "turnon", "yellowteam"]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    TURNON_FIELD_NUMBER: _ClassVar[int]
    YELLOWTEAM_FIELD_NUMBER: _ClassVar[int]
    position: _common_pb2.Robot
    turnon: bool
    yellowteam: bool
    def __init__(self, position: _Optional[_Union[_common_pb2.Robot, _Mapping]] = ..., yellowteam: bool = ..., turnon: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

BLUE: Color
DESCRIPTOR: _descriptor.FileDescriptor
FIRST_HALF: Half
FREE_BALL: Foul
FREE_KICK: Foul
GAME_ON: Foul
GOAL_KICK: Foul
HALT: Foul
KICKOFF: Foul
NONE: Color
NO_HALF: Half
NO_QUADRANT: Quadrant
OVERTIME_FIRST_HALF: Half
OVERTIME_SECOND_HALF: Half
PENALTY_KICK: Foul
PENALTY_SHOOTOUTS: Half
QUADRANT_1: Quadrant
QUADRANT_2: Quadrant
QUADRANT_3: Quadrant
QUADRANT_4: Quadrant
SECOND_HALF: Half
STOP: Foul
YELLOW: Color

class Frame(_message.Message):
    __slots__ = ["robots", "teamColor"]
    ROBOTS_FIELD_NUMBER: _ClassVar[int]
    TEAMCOLOR_FIELD_NUMBER: _ClassVar[int]
    robots: _containers.RepeatedCompositeFieldContainer[Robot]
    teamColor: Color
    def __init__(self, teamColor: _Optional[_Union[Color, str]] = ..., robots: _Optional[_Iterable[_Union[Robot, _Mapping]]] = ...) -> None: ...

class Robot(_message.Message):
    __slots__ = ["orientation", "robot_id", "x", "y"]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    ROBOT_ID_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    orientation: float
    robot_id: int
    x: float
    y: float
    def __init__(self, robot_id: _Optional[int] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., orientation: _Optional[float] = ...) -> None: ...

class Foul(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Color(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Quadrant(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Half(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



import vssref_common_pb2 as _vssref_common_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VSSRef_Placement(_message.Message):
    __slots__ = ["world"]
    WORLD_FIELD_NUMBER: _ClassVar[int]
    world: _vssref_common_pb2.Frame
    def __init__(self, world: _Optional[_Union[_vssref_common_pb2.Frame, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: command.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcommand.proto\x12\x17\x66ira_message.sim_to_ref\"R\n\x07\x43ommand\x12\n\n\x02id\x18\x01 \x01(\r\x12\x12\n\nyellowteam\x18\x02 \x01(\x08\x12\x12\n\nwheel_left\x18\x06 \x01(\x01\x12\x13\n\x0bwheel_right\x18\x07 \x01(\x01\"D\n\x08\x43ommands\x12\x38\n\x0erobot_commands\x18\x01 \x03(\x0b\x32 .fira_message.sim_to_ref.Commandb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'command_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMAND._serialized_start=42
  _COMMAND._serialized_end=124
  _COMMANDS._serialized_start=126
  _COMMANDS._serialized_end=194
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vssref_command.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import vssref_common_pb2 as vssref__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14vssref_command.proto\x12\x12VSSRef.ref_to_team\x1a\x13vssref_common.proto\"\xa9\x01\n\x0eVSSRef_Command\x12\x1a\n\x04\x66oul\x18\x01 \x01(\x0e\x32\x0c.VSSRef.Foul\x12 \n\tteamcolor\x18\x02 \x01(\x0e\x32\r.VSSRef.Color\x12&\n\x0c\x66oulQuadrant\x18\x03 \x01(\x0e\x32\x10.VSSRef.Quadrant\x12\x11\n\ttimestamp\x18\x04 \x01(\x01\x12\x1e\n\x08gameHalf\x18\x05 \x01(\x0e\x32\x0c.VSSRef.Halfb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vssref_command_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VSSREF_COMMAND._serialized_start=66
  _VSSREF_COMMAND._serialized_end=235
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: packet.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import command_pb2 as command__pb2
import replacement_pb2 as replacement__pb2
import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cpacket.proto\x12\x17\x66ira_message.sim_to_ref\x1a\rcommand.proto\x1a\x11replacement.proto\x1a\x0c\x63ommon.proto\"o\n\x06Packet\x12.\n\x03\x63md\x18\x01 \x01(\x0b\x32!.fira_message.sim_to_ref.Commands\x12\x35\n\x07replace\x18\x02 \x01(\x0b\x32$.fira_message.sim_to_ref.Replacement\"\x8d\x01\n\x0b\x45nvironment\x12\x0c\n\x04step\x18\x01 \x01(\r\x12\"\n\x05\x66rame\x18\x02 \x01(\x0b\x32\x13.fira_message.Frame\x12\"\n\x05\x66ield\x18\x03 \x01(\x0b\x32\x13.fira_message.Field\x12\x12\n\ngoals_blue\x18\x04 \x01(\r\x12\x14\n\x0cgoals_yellow\x18\x05 \x01(\r2_\n\x08Simulate\x12S\n\x08Simulate\x12\x1f.fira_message.sim_to_ref.Packet\x1a$.fira_message.sim_to_ref.Environment\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'packet_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PACKET._serialized_start=89
  _PACKET._serialized_end=200
  _ENVIRONMENT._serialized_start=203
  _ENVIRONMENT._serialized_end=344
  _SIMULATE._serialized_start=346
  _SIMULATE._serialized_end=441
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: replacement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11replacement.proto\x12\x17\x66ira_message.sim_to_ref\x1a\x0c\x63ommon.proto\"]\n\x10RobotReplacement\x12%\n\x08position\x18\x01 \x01(\x0b\x32\x13.fira_message.Robot\x12\x12\n\nyellowteam\x18\x05 \x01(\x08\x12\x0e\n\x06turnon\x18\x06 \x01(\x08\"?\n\x0f\x42\x61llReplacement\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\n\n\x02vx\x18\x03 \x01(\x01\x12\n\n\x02vy\x18\x04 \x01(\x01\"\x80\x01\n\x0bReplacement\x12\x36\n\x04\x62\x61ll\x18\x01 \x01(\x0b\x32(.fira_message.sim_to_ref.BallReplacement\x12\x39\n\x06robots\x18\x02 \x03(\x0b\x32).fira_message.sim_to_ref.RobotReplacementb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'replacement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROBOTREPLACEMENT._serialized_start=60
  _ROBOTREPLACEMENT._serialized_end=153
  _BALLREPLACEMENT._serialized_start=155
  _BALLREPLACEMENT._serialized_end=218
  _REPLACEMENT._serialized_start=221
  _REPLACEMENT._serialized_end=349
# @@protoc_insertion_point(module_scope)



import vssref_common_pb2 as _vssref_common_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VSSRef_Command(_message.Message):
    __slots__ = ["foul", "foulQuadrant", "gameHalf", "teamcolor", "timestamp"]
    FOULQUADRANT_FIELD_NUMBER: _ClassVar[int]
    FOUL_FIELD_NUMBER: _ClassVar[int]
    GAMEHALF_FIELD_NUMBER: _ClassVar[int]
    TEAMCOLOR_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    foul: _vssref_common_pb2.Foul
    foulQuadrant: _vssref_common_pb2.Quadrant
    gameHalf: _vssref_common_pb2.Half
    teamcolor: _vssref_common_pb2.Color
    timestamp: float
    def __init__(self, foul: _Optional[_Union[_vssref_common_pb2.Foul, str]] = ..., teamcolor: _Optional[_Union[_vssref_common_pb2.Color, str]] = ..., foulQuadrant: _Optional[_Union[_vssref_common_pb2.Quadrant, str]] = ..., timestamp: _Optional[float] = ..., gameHalf: _Optional[_Union[_vssref_common_pb2.Half, str]] = ...) -> None: ...
